<?php
/**
 * Call to action section
 *
 * @package Theme Palace
 * @subpackage Yule
 * @since Yule 1.0.0
 */
if ( ! function_exists( 'yule_add_cta_section' ) ) :
    /**
    * Add cta section
    *
    *@since Yule 1.0.0
    */
    function yule_add_cta_section() {
        $options = yule_get_theme_options();
        // Check if cta is enabled on frontpage
        $cta_enable = apply_filters( 'yule_section_status', true, 'cta_section_enable' );

        if ( true !== $cta_enable ) {
            return false;
        }
        // Get cta section details
        $section_details = array();
        $section_details = apply_filters( 'yule_filter_cta_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render cta section now.
        yule_render_cta_section( $section_details );
    }
endif;
add_action( 'yule_primary_content', 'yule_add_cta_section', 50 );

if ( ! function_exists( 'yule_get_cta_section_details' ) ) :
    /**
    * cta section details.
    *
    * @since Yule 1.0.0
    * @param array $input cta section details.
    */
    function yule_get_cta_section_details( $input ) {
        $options = yule_get_theme_options();

        // Content type.
        $content = array();
        $page_id = ! empty( $options['cta_content_page'] ) ? $options['cta_content_page'] : '';
        $args = array(
            'post_type'         => 'page',
            'page_id'           => $page_id,
            'posts_per_page'    => 1,
            );                    

        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['title']     = get_the_title();
                $page_post['excerpt']   = get_the_excerpt();
                $page_post['url']       = get_the_permalink();
                $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'large' ) : '';

                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// cta section content details.
add_filter( 'yule_filter_cta_section_details', 'yule_get_cta_section_details' );


if ( ! function_exists( 'yule_render_cta_section' ) ) :
  /**
   * Start cta section
   *
   * @return string cta content
   * @since Yule 1.0.0
   *
   */
   function yule_render_cta_section( $content_details = array() ) {
        $options = yule_get_theme_options();
        $btn_label = ! empty( $options['cta_btn_label'] ) ? $options['cta_btn_label'] : esc_html__( 'Know More', 'yule' );

        if ( empty( $content_details ) ) {
            return;
        } 

        foreach ( $content_details as $content ) : ?>
            <div id="call-to-action" class="relative">
                <div class="wrapper">
                    <article <?php echo ! empty( $content['image'] ) ? 'class="has-featured-image"' : ''; ?>>
                        <?php if ( ! empty( $content['image'] ) ) : ?>
                            <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
                            </div><!-- .featured-image -->
                        <?php endif; ?>

                        <div class="entry-container">
                            <?php if ( ! empty( $content['title'] ) ) : ?>
                                <div class="section-header">
                                    <h2 class="section-title"><?php echo esc_html( $content['title'] ); ?></h2>
                                </div><!-- .section-header -->
                            <?php endif; 

                            if ( ! empty( $content['excerpt'] ) ) : ?>
                                <div class="section-content">
                                    <?php echo esc_html( $content['excerpt'] ); ?>
                                </div><!-- .section-content -->
                            <?php endif; ?>

                            <div class="more-link">
                                <a href="<?php echo esc_url( $content['url'] ); ?>" class="btn btn-default"><?php echo esc_html( $btn_label ); ?></a>
                            </div><!-- .more-link -->
                        </div><!-- .entry-container -->
                    </article>
                </div><!-- .wrapper -->
            </div><!-- #call-to-action -->
        <?php endforeach;
    }
endif;