<?php
/**
 * Yule WooCoommerce compatibility hooks.
 *
 * This is the template that includes all WooCoommerce hooks to make the theme compatible with WooCommerce.
 *
 * @package Theme Palace
 * @subpackage Yule
 * @since Yule 1.0.0
 */

/**
 * WooCommerce setup function.
 *
 * @link https://docs.woocommerce.com/document/third-party-custom-theme-compatibility/
 * @link https://github.com/woocommerce/woocommerce/wiki/Enabling-product-gallery-features-(zoom,-swipe,-lightbox)-in-3.0.0
 *
 * @return void
 */
function yule_woocommerce_setup() {
	add_theme_support( 'woocommerce' );
	add_theme_support( 'wc-product-gallery-zoom' );
	add_theme_support( 'wc-product-gallery-lightbox' );
	add_theme_support( 'wc-product-gallery-slider' );
}
add_action( 'after_setup_theme', 'yule_woocommerce_setup' );

if ( ! function_exists( 'yule_woocommerce_product_columns_wrapper' ) ) {
	/**
	 * Product columns wrapper.
	 *
	 * @return  void
	 */
	function yule_woocommerce_product_columns_wrapper() {
		echo '	<div id="inner-content-wrapper" class="page-section">
	    			<div class="wrapper">';
	}
}
add_action( 'woocommerce_before_main_content', 'yule_woocommerce_product_columns_wrapper', 5 );

if ( ! function_exists( 'yule_woocommerce_product_columns_wrapper_close' ) ) {
	/**
	 * Product columns wrapper close.
	 *
	 * @return  void
	 */
	function yule_woocommerce_product_columns_wrapper_close() {
		echo '</div>
			</div>';
	}
}
add_action( 'woocommerce_after_main_content', 'yule_woocommerce_product_columns_wrapper_close', 20 );

/**
 * Remove default sidebar position.
 */
remove_action( 'woocommerce_sidebar', 'woocommerce_get_sidebar', 10 );

// Change number or products per row to 3
add_filter('loop_shop_columns', 'yule_loop_columns');

if ( ! function_exists( 'yule_loop_columns' ) ) {
	function yule_loop_columns() {
		return 3; // 3 products per row
	}
}